OiRA

# Πιστοποιητικό

Με το παρόν πιστοποιείται ότι η/ο επιχείρηση/οργανισμός με την επωνυμία

Sacrebleu & Fils European Trucking Ltd.

Ολοκλήρωσε την εκπόνηση της Μελέτης Εκτίμησης Επαγγελματικού Κινδύνου με το κλαδικό ψηφιακό εργαλείο “Transport routier” on 7 September 2019.

Ονοματεπώνυμο εργοδότη στο Πιστοποιητικό Departement/Region SIRET number Contact name

Το πιστοποιητικό σας για “Buckets and broomsticks” είναι για ιδιωτική χρήση, εκτός και αν εσείς επιλέξετε να το δημοσιοποιήσετε. Επιλέγοντας το κουμπί “Δημοσιοποίηση”, το πιστοποιητικό σας θα δημοσιοποιηθεί στον επίσημο ιστότοπο για το πρόγραμμα και τα εργαλεία OiRA website.

Εκτύπωση

Back

## certificate-public.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More